summaryrefslogtreecommitdiffstats
path: root/nuttx/configs/lm4f120-launchpad
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-03-08 13:29:09 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-03-08 13:29:09 -0600
commit3100722cdd78ff94412a760138e2fd4fdc319548 (patch)
tree40fef8e42b9d2ad55872feb5a32ee6cbf9390a0c /nuttx/configs/lm4f120-launchpad
parent39d69550a195f226b1985ebc62f760d286cd68c8 (diff)
All files and functions beginning with lm_ changed to tiva_
Diffstat (limited to 'nuttx/configs/lm4f120-launchpad')
-rw-r--r--nuttx/configs/lm4f120-launchpad/README.txt4
-rw-r--r--nuttx/configs/lm4f120-launchpad/include/board.h4
-rw-r--r--nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c28
-rw-r--r--nuttx/configs/lm4f120-launchpad/src/lm4f_boot.c4
-rw-r--r--nuttx/configs/lm4f120-launchpad/src/lm4f_ssi.c22
-rw-r--r--nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h2
6 files changed, 32 insertions, 32 deletions
diff --git a/nuttx/configs/lm4f120-launchpad/README.txt b/nuttx/configs/lm4f120-launchpad/README.txt
index 1add36d105..274c9758b8 100644
--- a/nuttx/configs/lm4f120-launchpad/README.txt
+++ b/nuttx/configs/lm4f120-launchpad/README.txt
@@ -337,7 +337,7 @@ IDEs
on the command line.
Startup files will probably cause you some headaches. The NuttX startup file
- is arch/arm/src/lm/lm_vectors.S.
+ is arch/arm/src/tiva/tiva_vectors.S.
NuttX EABI "buildroot" Toolchain
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -663,7 +663,7 @@ LM4F120 LaunchPad Configuration Options
to build the Stellaris Ethernet driver
CONFIG_LM_ETHLEDS - Enable to use Ethernet LEDs on the board.
CONFIG_LM_BOARDMAC - If the board-specific logic can provide
- a MAC address (via lm_ethernetmac()), then this should be selected.
+ a MAC address (via tiva_ethernetmac()), then this should be selected.
CONFIG_LM_ETHHDUPLEX - Set to force half duplex operation
CONFIG_LM_ETHNOAUTOCRC - Set to suppress auto-CRC generation
CONFIG_LM_ETHNOPAD - Set to suppress Tx padding
diff --git a/nuttx/configs/lm4f120-launchpad/include/board.h b/nuttx/configs/lm4f120-launchpad/include/board.h
index 7ac08d948f..5d86c6ea96 100644
--- a/nuttx/configs/lm4f120-launchpad/include/board.h
+++ b/nuttx/configs/lm4f120-launchpad/include/board.h
@@ -191,7 +191,7 @@
#ifndef __ASSEMBLY__
/************************************************************************************
- * Name: lm_boardinitialize
+ * Name: tiva_boardinitialize
*
* Description:
* All Stellaris architectures must provide the following entry point. This entry
@@ -200,7 +200,7 @@
*
************************************************************************************/
-void lm_boardinitialize(void);
+void tiva_boardinitialize(void);
/************************************************************************************
* Name: lm4f_ledinit, lm4f_setled, and lm4f_setleds
diff --git a/nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c b/nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c
index 6932994a93..8f08f095cd 100644
--- a/nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c
+++ b/nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c
@@ -48,7 +48,7 @@
#include "chip.h"
#include "up_arch.h"
#include "up_internal.h"
-#include "lm_gpio.h"
+#include "tiva_gpio.h"
#include "lmf4120-launchpad.h"
/****************************************************************************
@@ -112,7 +112,7 @@
/* Dump GPIO registers */
#ifdef CONFIG_DEBUG_LEDS
-# define led_dumpgpio(m) lm_dumpgpio(LED_GPIO, m)
+# define led_dumpgpio(m) tiva_dumpgpio(LED_GPIO, m)
#else
# define led_dumpgpio(m)
#endif
@@ -144,11 +144,11 @@ void lm4f_ledinit(void)
/* Configure Port E, Bit 1 as an output, initial value=OFF */
- led_dumpgpio("lm4f_ledinit before lm_configgpio()");
- lm_configgpio(GPIO_LED_R);
- lm_configgpio(GPIO_LED_G);
- lm_configgpio(GPIO_LED_B);
- led_dumpgpio("lm4f_ledinit after lm_configgpio()");
+ led_dumpgpio("lm4f_ledinit before tiva_configgpio()");
+ tiva_configgpio(GPIO_LED_R);
+ tiva_configgpio(GPIO_LED_G);
+ tiva_configgpio(GPIO_LED_B);
+ led_dumpgpio("lm4f_ledinit after tiva_configgpio()");
}
/****************************************************************************
@@ -168,25 +168,25 @@ void board_led_on(int led)
/* The GREEN component is illuminated at the final initialization step */
case 1:
- lm_gpiowrite(GPIO_LED_G, false);
+ tiva_gpiowrite(GPIO_LED_G, false);
break;
/* These will illuminate the BLUE component with on effect no RED and GREEN */
case 2:
- lm_gpiowrite(GPIO_LED_B, false);
+ tiva_gpiowrite(GPIO_LED_B, false);
break;
/* This will turn off RED and GREEN and turn RED on */
case 4:
- lm_gpiowrite(GPIO_LED_G, true);
- lm_gpiowrite(GPIO_LED_B, true);
+ tiva_gpiowrite(GPIO_LED_G, true);
+ tiva_gpiowrite(GPIO_LED_B, true);
/* This will illuminate the RED component with no effect on RED and GREEN */
case 3:
- lm_gpiowrite(GPIO_LED_R, false);
+ tiva_gpiowrite(GPIO_LED_R, false);
break;
}
}
@@ -209,14 +209,14 @@ void board_led_off(int led)
/* These will extinguish the BLUE component with no effect on RED and GREEN */
case 2:
- lm_gpiowrite(GPIO_LED_B, true);
+ tiva_gpiowrite(GPIO_LED_B, true);
break;
/* These will extinguish the RED component with on effect on RED and GREEN */
case 3:
case 4:
- lm_gpiowrite(GPIO_LED_R, true);
+ tiva_gpiowrite(GPIO_LED_R, true);
break;
}
}
diff --git a/nuttx/configs/lm4f120-launchpad/src/lm4f_boot.c b/nuttx/configs/lm4f120-launchpad/src/lm4f_boot.c
index 537dc15e35..78fda4823e 100644
--- a/nuttx/configs/lm4f120-launchpad/src/lm4f_boot.c
+++ b/nuttx/configs/lm4f120-launchpad/src/lm4f_boot.c
@@ -61,7 +61,7 @@
************************************************************************************/
/************************************************************************************
- * Name: lm_boardinitialize
+ * Name: tiva_boardinitialize
*
* Description:
* All Stellaris architectures must provide the following entry point. This entry
@@ -70,7 +70,7 @@
*
************************************************************************************/
-void lm_boardinitialize(void)
+void tiva_boardinitialize(void)
{
/* Configure SPI chip selects if 1) SSI is not disabled, and 2) the weak function
* lm_ssiinitialize() has been brought into the link.
diff --git a/nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h b/nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h
index b6f064b240..450fd8ea8c 100644
--- a/nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h
+++ b/nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h
@@ -45,7 +45,7 @@
#include <nuttx/compiler.h>
#include "chip.h"
-#include "lm_gpio.h"
+#include "tiva_gpio.h"
/************************************************************************************
* Definitions
diff --git a/nuttx/configs/lm4f120-launchpad/src/lm4f_ssi.c b/nuttx/configs/lm4f120-launchpad/src/lm4f_ssi.c
index 34a6cba9be..b26f074244 100644
--- a/nuttx/configs/lm4f120-launchpad/src/lm4f_ssi.c
+++ b/nuttx/configs/lm4f120-launchpad/src/lm4f_ssi.c
@@ -49,7 +49,7 @@
#include "up_arch.h"
#include "chip.h"
-#include "lm_gpio.h"
+#include "tiva_gpio.h"
#include "lmf4120-launchpad.h"
/* The LM4F LaunchPad microSD CS is on SSI0 */
@@ -72,7 +72,7 @@
#if defined(CONFIG_DEBUG_SPI) && defined(CONFIG_DEBUG_VERBOSE)
# define ssivdbg lldbg
-# define ssi_dumpgpio(m) lm_dumpgpio(SDCCS_GPIO, m)
+# define ssi_dumpgpio(m) tiva_dumpgpio(SDCCS_GPIO, m)
#else
# define ssivdbg(x...)
# define ssi_dumpgpio(m)
@@ -99,32 +99,32 @@ void weak_function lm4f_ssiinitialize(void)
}
/****************************************************************************
* The external functions, lm_spiselect and lm_spistatus must be provided
* by board-specific logic. The are implementations of the select and status
* methods SPI interface defined by struct spi_ops_s (see include/nuttx/spi/spi.h).
* All othermethods (including lm_spiinitialize()) are provided by common
* logic. To use this common SPI logic on your board:
*
* 1. Provide lm_spiselect() and lm_spistatus() functions in your
* board-specific logic. This function will perform chip selection and
* status operations using GPIOs in the way your board is configured.
* 2. Add a call to lm_spiinitialize() in your low level initialization
* logic
* 3. The handle returned by lm_spiinitialize() may then be used to bind the
* SPI driver to higher level logic (e.g., calling
* mmcsd_spislotinitialize(), for example, will bind the SPI driver to
* the SPI MMC/SD driver).
*
****************************************************************************/
-void lm_spiselect(FAR struct spi_dev_s *dev, enum spi_dev_e devid, bool selected)
+void tiva_spiselect(FAR struct spi_dev_s *dev, enum spi_dev_e devid, bool selected)
{
ssidbg("devid: %d CS: %s\n", (int)devid, selected ? "assert" : "de-assert");
- ssi_dumpgpio("lm_spiselect() Entry");
- ssi_dumpgpio("lm_spiselect() Exit");
+ ssi_dumpgpio("tiva_spiselect() Entry");
+ ssi_dumpgpio("tiva_spiselect() Exit");
}
-uint8_t lm_spistatus(FAR struct spi_dev_s *dev, enum spi_dev_e devid)
+uint8_t tiva_spistatus(FAR struct spi_dev_s *dev, enum spi_dev_e devid)
{
ssidbg("Returning SPI_STATUS_PRESENT\n");
return SPI_STATUS_PRESENT;
@@ -99,32 +99,32 @@ void weak_function lm4f_ssiinitialize(void)
}
/****************************************************************************
- * The external functions, lm_spiselect and lm_spistatus must be provided
+ * The external functions, tiva_spiselect and tiva_spistatus must be provided
* by board-specific logic. The are implementations of the select and status
* methods SPI interface defined by struct spi_ops_s (see include/nuttx/spi/spi.h).
@@ -99,32 +99,32 @@ void weak_function lm4f_ssiinitialize(void)
* by board-specific logic. The are implementations of the select and status
* methods SPI interface defined by struct spi_ops_s (see include/nuttx/spi/spi.h).
- * All othermethods (including lm_spiinitialize()) are provided by common
+ * All othermethods (including tiva_spiinitialize()) are provided by common
* logic. To use this common SPI logic on your board:
*
@@ -99,32 +99,32 @@ void weak_function lm4f_ssiinitialize(void)
* logic. To use this common SPI logic on your board:
*
- * 1. Provide lm_spiselect() and lm_spistatus() functions in your
+ * 1. Provide tiva_spiselect() and tiva_spistatus() functions in your
* board-specific logic. This function will perform chip selection and
* status operations using GPIOs in the way your board is configured.
@@ -99,32 +99,32 @@ void weak_function lm4f_ssiinitialize(void)
* board-specific logic. This function will perform chip selection and
* status operations using GPIOs in the way your board is configured.
- * 2. Add a call to lm_spiinitialize() in your low level initialization
+ * 2. Add a call to tiva_spiinitialize() in your low level initialization
* logic
@@ -99,32 +99,32 @@ void weak_function lm4f_ssiinitialize(void)
* logic
- * 3. The handle returned by lm_spiinitialize() may then be used to bind the
+ * 3. The handle returned by tiva_spiinitialize() may then be used to bind the
* SPI driver to higher level logic (e.g., calling
* mmcsd_spislotinitialize(), for example, will bind the SPI driver to